const {
	globalData: {
		baseUrl
	}
} = getApp();
export class Http {
	constructor() {}
	request({
		url,
		data = {},
		method = 'GET',
		header,
		callback = '',
		responseType,
		contentType = 'application/json'
	} = {}) {
		let _this = this;
		uni.showLoading({
			title: 'Loading...',
			icon: 'loading',
			mask: true
		});
		return new Promise((resolve, reject) => {
			uni.request({
				url: `${baseUrl}${url}`,
				data,
				method,
				header: {
					'Content-Type': contentType,
				},
				callback,
				responseType,
				success: (res) => {
					let statusCode = res.statusCode;
					let resData = res.data;
					if (callback) return callback(resData.data);
					uni.hideLoading();

					if (statusCode == 200) {
						// 如果请求返回的是文件流，需要单独处理
						if (responseType == 'arraybuffer') {
							resolve(resData);
							return;
						}
						if (resData.code == 200) {
							resolve(resData.data);
						} else {
							uni.showModal({
								title: '提示',
								content: resData.msg || '操作失败',
								showCancel: false,
								confirmText: '确认'
							});
							reject(resData, statusCode)
						}
					} else if (statusCode == 404) {
						console.log('接口不存在');
					} else if (statusCode == 401) {
						uni.reLaunch({
							url: '/pages/login/login'
						});
					} else {
						uni.showModal({
							title: '提示',
							content: res.data.msg,
							showCancel: false,
							confirmText: '确认'
						});
						reject(resData, statusCode)
					}
				},
				fail: (err) => {
					console.log('fail', err);
					uni.showModal({
						title: '提示',
						content: `网络请求失败`,
						showCancel: false,
						confirmText: '确认'
					});
				},
				complete: function(res) {
					uni.hideLoading && uni.hideLoading();
					uni.hideNavigationBarLoading() && uni.hideNavigationBarLoading();
				}
			})
		})
	}
}
